Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2576)

Unified Diff: chrome/browser/instant/instant_model_observer.h

Issue 12386019: Instant: Use only one hidden WebContents per profile. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/instant/instant_model_observer.h
diff --git a/chrome/browser/instant/instant_model_observer.h b/chrome/browser/instant/instant_model_observer.h
index 1985fcc177eab45dfd4adb69cd8dc472f8a8434b..2a208f305991dead7d38d76d9c350eeae8b47b69 100644
--- a/chrome/browser/instant/instant_model_observer.h
+++ b/chrome/browser/instant/instant_model_observer.h
@@ -7,12 +7,12 @@
class InstantModel;
-// This class defines the observer interface for the |InstantModel|.
+// This class defines the observer interface for the InstantModel.
class InstantModelObserver {
public:
- // Informs the observer that the preview state has changed. This can mean
- // either the model state changed or the contents of the preview changed.
- virtual void PreviewStateChanged(const InstantModel& model) = 0;
+ // Informs the observer that the overlay state has changed. This can mean
+ // either the model state changed or the contents of the overlay changed.
+ virtual void OverlayStateChanged(const InstantModel& model) = 0;
protected:
~InstantModelObserver() {}

Powered by Google App Engine
This is Rietveld 408576698